'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _svgstore = require('svgstore');

var _svgstore2 = _interopRequireDefault(_svgstore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var iconDir = getIconDir();

var FeatherPlugin = function () {
  function FeatherPlugin(options) {
    _classCallCheck(this, FeatherPlugin);

    if (!options instanceof Array) {
      throw new Error('An options array is required');
    }

    var copyAttrs = options.copyAttrs,
        cleanObjects = options.cleanObjects,
        svgAttrs = options.svgAttrs,
        symbolAttrs = options.symbolAttrs,
        whitelist = options.whitelist,
        template = options.template,
        line = options.line,
        output = options.output;


    this.generator = (0, _svgstore2.default)({
      inline: true,
      copyAttrs: copyAttrs || ['fill', 'stroke-width', 'stroke-linecap', 'stroke-linejoin'],
      cleanObjects: cleanObjects,
      svgAttrs: svgAttrs,
      symbolAttrs: symbolAttrs
    });

    this.whitelist = whitelist;
    this.templateName = template;
    this.lineNumber = line || 0;
    this.output = output;
    this.first = true;
  }

  _createClass(FeatherPlugin, [{
    key: 'apply',
    value: function apply(compiler) {
      var _this = this;

      var context = compiler.options.context;
      var generator = this.generator,
          whitelist = this.whitelist,
          lineNumber = this.lineNumber;


      var templatePath = _path2.default.resolve(context, this.templateName);
      var outputPath = _path2.default.resolve(context, this.output);

      compiler.plugin('emit', function (compilation, callback) {
        if (!_this.first) {
          return callback();
        }

        var icons = getIcons(whitelist);

        icons.forEach(function (icon) {
          generator.add(icon[0], icon[1]);
        });

        writeOutput(templatePath, lineNumber, generator, outputPath);
        _this.first = false;

        callback();
      });
    }
  }]);

  return FeatherPlugin;
}();

function writeOutput(template, line, generator, output) {
  var contents = _fs2.default.readFileSync(template, 'utf8').split('\n');

  contents.splice(line, 0, generator);

  _fs2.default.writeFileSync(output, contents.join('\n'));
}

function getIcons(whitelist) {
  var icons = [];

  _fs2.default.readdirSync(iconDir).forEach(function (category) {
    var dir = _path2.default.join(iconDir, category);

    var files = _fs2.default.readdirSync(dir).map(function (file) {
      return file.replace('.svg', '');
    });

    var names = filterNames(whitelist, files);

    names.forEach(function (name) {
      var svg = _fs2.default.readFileSync(_path2.default.join(dir, name + '.svg'), 'utf8');

      icons.push([name, transform(svg)]);
    });
  });

  return icons;
}

function filterNames(whitelist, files) {
  return files.filter(function (file) {
    return whitelist.indexOf(file) !== -1;
  });
}

function getIconDir() {
  var test = _fs2.default.existsSync(_path2.default.join(__dirname, '../node_modules'));

  return _path2.default.join(__dirname, '../' + (test ? 'node_modules' : '..') + '/feather-icons/icons');
}

var transform = function transform(svg) {
  return svg.replace(/ stroke="#000"/g, '');
};

// Fix ES5 require
FeatherPlugin.default = FeatherPlugin;
module.exports = FeatherPlugin;